@@ -1074,6 +1074,24 @@ _gst_mini_object_is_writable (PyObject * self, PyObject * args)
   return res;
 }
 
+static PyObject *
+_gst_mini_object_to_subclass (PyObject * self, PyObject * args)
+{
+  PyObject *py_miniobj;
+  GstMiniObject *mini_object;
+
+  py_miniobj = PyTuple_GetItem (args, 0);
+  if (py_miniobj == NULL) {
+    PyErr_SetString (PyExc_TypeError, "Expected a PyGObject");
+    return NULL;
+  }
+
+  mini_object = pyg_boxed_get (py_miniobj, GstMiniObject);
+
+  return pyg_boxed_new (GST_MINI_OBJECT_TYPE (mini_object), mini_object, TRUE,
+      TRUE);
+}
+
 static PyObject *
 _gst_caps_get_structure (PyObject * self, PyObject * args)
 {
@@ -1413,7 +1431,7 @@ _gst_buffer_get_dts (PyObject * self, PyObject * args)
 {
   DECLARE_BUFFER (args);
 
-  return PyLong_FromUnsignedLong (buffer->dts);
+  return PyLong_FromUnsignedLongLong (buffer->dts);
 }
 
 static gboolean
@@ -1467,7 +1485,7 @@ _gst_buffer_get_pts (PyObject * self, PyObject * args)
 {
   DECLARE_BUFFER (args);
 
-  return PyLong_FromUnsignedLong (buffer->pts);
+  return PyLong_FromUnsignedLongLong (buffer->pts);
 }
 
 static PyObject *
@@ -1498,7 +1516,7 @@ _gst_buffer_get_duration (PyObject * self, PyObject * args)
 {
   DECLARE_BUFFER (args);
 
-  return PyLong_FromUnsignedLong (buffer->duration);
+  return PyLong_FromUnsignedLongLong (buffer->duration);
 }
 
 static PyObject *
@@ -1529,7 +1547,7 @@ _gst_buffer_get_offset (PyObject * self, PyObject * args)
 {
   DECLARE_BUFFER (args);
 
-  return PyLong_FromUnsignedLong (buffer->offset);
+  return PyLong_FromUnsignedLongLong (buffer->offset);
 }
 
 static PyObject *
@@ -1560,7 +1578,7 @@ _gst_buffer_get_offset_end (PyObject * self, PyObject * args)
 {
   DECLARE_BUFFER (args);
 
-  return PyLong_FromUnsignedLong (buffer->offset_end);
+  return PyLong_FromUnsignedLongLong (buffer->offset_end);
 }
 
 static PyObject *
@@ -1658,6 +1676,52 @@ _gst_buffer_override_unmap (PyObject * self, PyObject * args)
   return success;
 }
 
+static PyObject *
+_gst_pad_probe_info_writable_object (PyObject * self, PyObject * args)
+{
+  PyObject *py_info = PyTuple_GetItem (args, 0);
+  if (py_info == NULL) {
+    PyErr_SetString (PyExc_TypeError, "Expected a PyGObject");
+    return NULL;
+  }
+
+  GstPadProbeInfo *info = pyg_boxed_get (py_info, GstPadProbeInfo);
+  if (info->data == NULL)
+    return NULL;
+
+  /* Make object writable and transfer ownership to python */
+  GstMiniObject *mini_object = GST_MINI_OBJECT (info->data);
+  mini_object = gst_mini_object_make_writable (mini_object);
+  info->data = NULL;
+  return pyg_boxed_new (GST_MINI_OBJECT_TYPE (mini_object), mini_object, FALSE,
+      TRUE);
+}
+
+static PyObject *
+_gst_pad_probe_info_set_object (PyObject * self, PyObject * args)
+{
+  PyObject *py_info = PyTuple_GetItem (args, 0);
+  if (py_info == NULL) {
+    PyErr_SetString (PyExc_TypeError, "Expected a PyGObject");
+    return NULL;
+  }
+  PyObject *py_obj = PyTuple_GetItem (args, 1);
+  if (py_obj == NULL) {
+    PyErr_SetString (PyExc_TypeError, "Expected a PyGObject");
+    return NULL;
+  }
+
+  GstPadProbeInfo *info = pyg_boxed_get (py_info, GstPadProbeInfo);
+  gst_clear_mini_object (&info->data);
+  if (py_obj != Py_None) {
+    GstMiniObject *obj = pyg_boxed_get (py_obj, GstMiniObject);
+    info->data = gst_mini_object_ref (obj);
+  }
+
+  Py_INCREF (Py_None);
+  return Py_None;
+}
+
 /* *INDENT-OFF* */
 static PyMethodDef _gi_gst_functions[] = {
   {"trace", (PyCFunction) _wrap_gst_trace, METH_VARARGS, NULL},
@@ -1684,6 +1748,7 @@ static PyMethodDef _gi_gst_functions[] = {
   {"mini_object_is_writable", (PyCFunction) _gst_mini_object_is_writable, METH_VARARGS, NULL},
   {"mini_object_flags", (PyCFunction) _gst_mini_object_flags, METH_VARARGS, NULL},
   {"mini_object_set_flags", (PyCFunction) _gst_mini_object_set_flags, METH_VARARGS, NULL},
+  {"mini_object_to_subclass", (PyCFunction) _gst_mini_object_to_subclass, METH_VARARGS, NULL},
 
   {"event_get_structure", (PyCFunction) _gst_event_get_structure, METH_VARARGS, NULL},
   {"event_writable_structure", (PyCFunction) _gst_event_writable_structure, METH_VARARGS, NULL},
@@ -1705,6 +1770,9 @@ static PyMethodDef _gi_gst_functions[] = {
   {"buffer_get_offset_end", (PyCFunction) _gst_buffer_get_offset_end, METH_VARARGS, NULL},
   {"buffer_set_offset_end", (PyCFunction) _gst_buffer_set_offset_end, METH_VARARGS, NULL},
 
+  {"pad_probe_info_writable_object", (PyCFunction)_gst_pad_probe_info_writable_object, METH_VARARGS, NULL},
+  {"pad_probe_info_set_object", (PyCFunction)_gst_pad_probe_info_set_object, METH_VARARGS, NULL},
+
   {"_get_object_ptr", (PyCFunction) _gst_get_object_ptr, METH_VARARGS, NULL},
   {NULL, NULL, 0, NULL}
 };
